@@ -333,7 +333,7 @@ class DataTransformer(MPTTModel):
         Accessory,
         on_delete=models.CASCADE,
         blank=True,
-        null=False
+        null=True
     )
 
 
