@@ -213,7 +213,7 @@ class HardwareIOSerializer(serializers.ModelSerializer):
 
 
 class DataTransformerConstantsSerializer(serializers.ModelSerializer):
-    data_transformer = serializers.PrimaryKeyRelatedField(many=True, read_only=True)
+    datatransformer = serializers.PrimaryKeyRelatedField(many=True, read_only=True)
 
     class Meta:
         model = DataTransformerConstants
@@ -222,7 +222,7 @@ class DataTransformerConstantsSerializer(serializers.ModelSerializer):
 
 
 class DataTransformerTreeSerializer(serializers.ModelSerializer):
-    data_transformer_constants = DataTransformerConstantsSerializer(many=True)
+    datatransformerconstants = DataTransformerConstantsSerializer(many=True)
     children = serializers.SerializerMethodField(source='get_children')
     class Meta:
         model=DataTransformer
